@@ -4,7 +4,8 @@ from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.settings import CONTENT_MEDIA_URL
-from mezzanine.core.forms import OrderableAdminForm
+from mezzanine.core.forms import OrderableAdminForm, TinyMceWidget
+from mezzanine.core.models import HtmlField
 
 
 media_url = CONTENT_MEDIA_URL.strip("/")
@@ -39,9 +40,10 @@ class DisplayableAdmin(admin.ModelAdmin):
     search_fields = ("title", "body",)
     date_hierarchy = "publish_date"
     radio_fields = {"status": admin.HORIZONTAL}
+    formfield_overrides = {HtmlField: {"widget": TinyMceWidget}}
     fieldsets = (
         (None, {"fields": ("title", ("status", "publish_date"), "content")}),
-        (_("Meta data"), {"fields": ("description", "keywords"), 
+        (_("Meta data"), {"fields": ("slug", "description", "keywords"), 
             "classes": ("collapse-closed",)},),
     )
 
